﻿Fluke Calibration                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek MSO Get Digital Threshold Values VISA /9500
DATE:                  2018-03-16 15:30:42
AUTHOR:                Fluke
REVISION:              $Revision: 23119 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       2
NUMBER OF LINES:       380
CONFIGURATION:         Datron 9500
CONFIGURATION:         Datron 9510 on channel 1
=============================================================================
#
#  Procedure Author:
#        DAC, CAD, GMO
#
#  Models Covered:
#        MSO2012,   MSO2014,   MSO2024
#        MSO2002B,  MSO2004B,  MSO2012B,  MSO2014B,     MSO2022B,  MSO2024B
#        MSO3012,   MSO3014,   MSO2032,   MSO3034,      MSO3052,   MSO3054
#        MSO4032,   MSO4034,   MSO4054,   MSO4104
#        MSO4014B,  MSO4034B,  MSO4054B,  MSO4102B(-L), MSO4104B(-L)
#        MDO4014-3, MDO4034-3, MDO4054-3, MDO4054-6,    MDO4104-3, MDO4104-6
#        MSO5034,   MSO5054,   MSO5104,   MSO5204
#
#  Source:
#        MSO2000B and DPO2000B Series Oscilloscopes
#        Specification and Performance Verification Technical Reference
#        PN 077-0735-00
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
#  Memory Register Usage:
#
#    M[100] - M[115]:  Channel state (0 or 1)
#    M[120] - M[135]:  Average transition voltage
#    M[140] - M[155]:  Average transition voltage accuracy
#    M[160] - M[175]:  Average transition voltage found (0 or 1)
#
#    @iState: Index offset to access channel state in M registers.
#    @iVolt:  Index offset to access voltage in M registers.
#    @iAcc:   Index offset to access voltage accuracy in M registers.
#    @iFound: Index offset to access voltage found in M registers.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  HEAD         -2 Threshold: [V @Threshold] V
  1.002  MATH         Conf = CONF("Datron 9500")

  1.003  DO
  1.004  VISA         *CLS;*RST
  1.005  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA

  1.006  IF           NOT(@Abort)
  1.007  VISA         HEAD OFF;:SELECT:CH1 OFF;CH2 OFF;CH3 OFF;CH4 OFF
  1.008  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.009  ENDIF

  1.010  IF           @Abort
  1.011  END
  1.012  ENDIF

  1.013  IF           @ShowConnection

  1.014  IF           FIND(@ModelNum, "MSO2", 1)
  1.015  MATH         Series = "MSO2000"
  1.016  ELSEIF       FIND(@ModelNum, "MDO3", 1)
  1.017  MATH         Series = "MDO3000"
  1.018  ELSEIF       FIND(@ModelNum, "MSO3", 1)
  1.019  MATH         Series = "MSO3000"
  1.020  ELSEIF       FIND(@ModelNum, "MDO4", 1)
  1.021  MATH         Series = "MDO4000"
  1.022  ELSEIF       FIND(@ModelNum, "MSO4", 1)
  1.023  MATH         Series = "MSO4000"
  1.024  ELSEIF       FIND(@ModelNum, "MSO5", 1)
  1.025  MATH         Series = "MSO5000"
  1.026  ELSE
  1.027  DISP         [V @ModelNum] not supported!
  1.028  MATH         @Abort = 1
  1.029  END
  1.030  ENDIF

  1.031  IF           FIND(@ModelNum, "B", 1)
  1.032  MATH         Series = Series & "B"
  1.033  ENDIF

  1.034  MATH         MDO3  = FIND(@ModelNum, "MDO3", 1)
  1.035  MATH         MSO2  = FIND(@ModelNum, "MSO2", 1)
  1.036  MATH         MSO3  = FIND(@ModelNum, "MSO3", 1)

  1.037  HEAD         -2 Threshold: [V @Threshold] V

  1.038  IF           MSO2 || MSO3 || MDO3
  1.039  DISP         Disconnect all clip leads from P6316 Test Probe.
  1.039  DISP
  1.039  DISP         Connect P6316 Test Probe to 0.1 in pin adapter.
  1.039  DISP
  1.039  DISP         Connect the P6316 Test Probe to DUT.
  1.039  DISP
  1.039  DISP         Connect the CH 1 Active Head to the pin adapter
  1.039  DISP         using a 50 Ohm feedthrough.

  1.040  ELSEIF       ZCMP(Series, "MSO4000")

  1.041  DO
  1.042  MEMI         Select connection method.
  1.042  MEMI
  1.042  MEMI         1. P6516 Test Probe and 0.1 in pin adapter, or
  1.042  MEMI
  1.042  MEMI         2. Cable Assembly (PN 174-4535-00).
  1.043  UNTIL        (MEM == 1) || (MEM == 2)

  1.044  IF           MEM == 1
  1.045  DISP         Disconnect all clip leads from P6516 Test Probe.
  1.045  DISP
  1.045  DISP         Connect P6516 Test Probe to 0.1 in pin adapter.
  1.045  DISP
  1.045  DISP         Connect the P6516 Test Probe to DUT.
  1.045  DISP
  1.045  DISP         Connect the CH 1 Active Head to the pin adapter.
  1.046  ELSE
  1.047  DISP         Connect Cable Assembly to DUT.
  1.047  DISP
  1.047  DISP         Connect the CH 1 Active Head to Cable Assembly
  1.047  DISP         using a 50 Ohm feedthrough.
  1.048  ENDIF

  1.049  ELSE         ; MDO4000, MSO4000B, MSO5000

  1.050  DO
  1.051  MEMI         Select connection method.
  1.051  MEMI
  1.051  MEMI         1. P6616 Test Probe and 0.1 in pin adapter, or
  1.051  MEMI
  1.051  MEMI         2. Calibration Adapter (PN 067-2121-00).
  1.052  UNTIL        (MEM == 1) || (MEM == 2)

  1.053  IF           MEM == 1
  1.054  DISP         Disconnect all clip leads from P6616 Test Probe.
  1.054  DISP
  1.054  DISP         Connect P6616 Test Probe to 0.1 in pin adapter.
  1.054  DISP
  1.054  DISP         Connect the P6616 Test Probe to DUT.
  1.054  DISP
  1.054  DISP         Connect the CH 1 Active Head to the pin adapter.
  1.055  ELSE
  1.056  DISP         Connect Calibration Adapter to DUT.
  1.056  DISP
  1.056  DISP         Connect the CH 1 Active Head to Calibration Adapter
  1.056  DISP         using a 50 Ohm feedthrough.
  1.057  ENDIF

  1.058  ENDIF

  1.059  MATH         @ShowConnection = 0
  1.060  ENDIF        ; @ShowConnection

# Set the displayed state of all the digital inputs to On.
  1.061  VISA         SEL:DALL ON
  1.062  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA

  1.063  MATH         LeadingDigit = SUB(@ModelNum, 4, 1)
  1.064  MATH         L[1] = ZCMP(LeadingDigit, "2")
  1.065  MATH         L[1] = ZCMP(LeadingDigit, "3") || L[1]
  1.066  MATH         L[1] = ZCMP(LeadingDigit, "4") || L[1]

  1.067  IF           NOT(@Abort)

  1.068  IF           L[1]
  1.069  MATH         Source = "DIG"
  1.070  ELSE
  1.071  MATH         Source = "DIGITALALL"
  1.072  ENDIF

  1.073  VISA         DAT:SOU [V Source];ENC ASCI
  1.074  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.075  ENDIF

  1.076  IF           NOT(@Abort)
  1.077  VISA         DAT:START 1;STOP 1
  1.078  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.079  ENDIF

# MSO2000, MSO2000B, MSO4000, MDO4000, MSO4000B
  1.080  IF           L[1]

# Call CLEARM to clear Vertical Button Labels.
  1.081  IF           NOT(@Abort)
  1.082  VISA         CLEARM
  1.083  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.084  ENDIF

# Call CLEARM to clear Horizontal Button Labels.
  1.085  IF           NOT(@Abort)
  1.086  VISA         CLEARM
  1.087  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.088  ENDIF

  1.089  ENDIF

  1.090  IF           NOT(@Abort)
  1.091  MATH         Ch = 0

  1.092  DO
  1.093  VISA         D[V Ch]:THRESHOLD [V @Threshold]
# Delete when debugged for MSO5000.
  1.094  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.095  MATH         Ch = Ch + 1
  1.096  UNTIL        Ch > 15

# Set flags to assume all required states/data is achieved.
  1.097  MATH         AllLow  = 1; LowToHigh = 1
  1.098  MATH         AllHigh = 1; HighToLow = 1

  1.099  HEAD         -2 Threshold: [V @Threshold] V (Low to High)
  1.100  VISA         TRIG:A:EDGE:SOU D0;SLO RIS

# Define Waveform Preamble necessary for certain DUT series.
  1.101  IF           FIND(@ModelNum, "MSO2", 1)
  1.102  VISA         WFMOUTPRE:ENCDG ASCI
  1.103  VISA         WFMOUTPRE:COMPOSITION SINGULAR_YT
  1.104  ENDIF

# Make sure all channels are low at starting voltage.
  1.105  MATH         Voltage = @LowVoltage; MEM = Voltage
  1.106  9500         V                                                 S  L
  1.107  WAIT         [D3000]
  1.108  CALL         Sub Tek MSO Read Digital Data VISA

# Abort if all channels are not initially low.
  1.109  MATH         Ch = 0
  1.110  MATH         AllLow = NOT(MGET(Ch + @iState))
  1.111  MATH         Ch = 1

  1.112  DO
  1.113  MATH         AllLow = AllLow || NOT(MGET(Ch + @iState))
  1.114  MATH         Ch = Ch + 1
  1.115  UNTIL        Ch > 15

  1.116  ENDIF        ; NOT(@Abort)

  1.117  IF           AllLow && NOT(@Abort)
# Initialize "Transition Found" flags to false.
  1.118  MATH         Ch = 0

  1.119  DO
  1.120  MATH         MSET((Ch + @iFound), 0)
  1.121  MATH         Ch = Ch + 1
  1.122  UNTIL        Ch > 15

# Get low to high transition value.
  1.123  DO
  1.124  MATH         MEM = Voltage
  1.125  9500         V                                                 S  L
  1.126  WAIT         [D3000]
  1.127  CALL         Sub Tek MSO Read Digital Data VISA
  1.128  MATH         Ch = 0

  1.129  DO

# Save transition voltage and reference accuracy.
  1.130  IF           NOT(MGET(Ch + @iFound)) && MGET(Ch + @iState)
  1.131  MATH         MSET((Ch + @iVolt), Voltage)
  1.132  MATH         MSET((Ch + @iAcc), REFACC())
  1.133  MATH         MSET((Ch + @iFound), 1)
  1.134  ENDIF

  1.135  MATH         Ch = Ch + 1
  1.136  UNTIL        Ch > 15

  1.137  MATH         Voltage = Voltage + 10E-3
  1.138  UNTIL        @FoundVoltages || (Voltage > @HighVoltage)

  1.139  MATH         LowToHigh = @FoundVoltages
  1.140  ENDIF        ; AllLow && NOT(@Abort)

  1.141  IF           LowToHigh && NOT(@Abort)
  1.142  HEAD         -2 Threshold: [V @Threshold] V (High to Low)
  1.143  TARGET
  1.144  VISA         TRIG:A:EDGE:SOU D0;SLO FALL
  1.145  MATH         Voltage = @HighVoltage; MEM = Voltage
  1.146  9500         V                                                 S  L
  1.147  WAIT         [D3000]
  1.148  CALL         Sub Tek MSO Read Digital Data VISA

# Abort if all channels are not initially high.
  1.149  MATH         Ch = 0
  1.150  MATH         AllHigh = MGET(Ch + @iState)
  1.151  MATH         Ch = 1

  1.152  DO
  1.153  MATH         AllHigh = AllHigh && MGET(Ch + @iState)
  1.154  MATH         Ch = Ch + 1
  1.155  UNTIL        Ch > 15

  1.156  ENDIF        ; LowToHigh && NOT(@Abort)

  1.157  IF           AllHigh && NOT(@Abort)
# Initialize "Transition Found" flags to false.
  1.158  MATH         Ch = 0

  1.159  DO
  1.160  MATH         MSET((Ch + @iFound), 0)
  1.161  MATH         Ch = Ch + 1
  1.162  UNTIL        Ch > 15

# Get high to low transition value.
  1.163  DO
  1.164  MATH         MEM = Voltage
  1.165  9500         V                                                 S  L
  1.166  WAIT         [D3000]
  1.167  CALL         Sub Tek MSO Read Digital Data VISA
  1.168  MATH         Ch = 0

  1.169  DO

# Save average transition voltage and reference accuracy.
  1.170  IF           NOT(MGET(Ch + @iFound)) && NOT(MGET(Ch + @iState))
  1.171  MATH         Avg = (MGET(Ch + @iVolt) + Voltage) / 2
  1.172  MATH         MSET(Ch + @iVolt, Avg)
  1.173  MATH         Acc = RSS2(MGET(Ch + @iAcc), REFACC()) / Conf * 2
  1.174  MATH         MSET((Ch + @iAcc), Acc)
  1.175  MATH         MSET((Ch + @iFound), 1)
  1.176  ENDIF

  1.177  MATH         Ch = Ch + 1
  1.178  UNTIL        Ch > 15

  1.179  MATH         Voltage = Voltage - 10E-3
  1.180  UNTIL        @FoundVoltages || (Voltage < @LowVoltage)

  1.181  MATH         HighToLow = @FoundVoltages
  1.182  ENDIF        ; AllHigh && NOT(@Abort)

  1.183  IF           AllLow && LowToHigh && AllHigh && HighToLow
  1.184  MATH         @GotData = 1; Done = 1
  1.185  ELSE
  1.186  MATH         @GotData = 0

  1.187  IF           NOT(AllLow)
  1.188  MATH         Msg = "All channels are not initially low."
  1.189  ELSEIF       NOT(LowToHigh)
  1.190  MATH         Msg = "All channels did not transition to high."
  1.191  ELSEIF       NOT(AllHigh)
  1.192  MATH         Msg = "All channels are not initially high."
  1.193  ELSEIF       NOT(HighToLow)
  1.194  MATH         Msg = "All channels did not transition to low."
  1.195  ENDIF

  1.196  OPBR         -z [V Msg]
  1.196  OPBR
  1.196  OPBR         Do you wish to try again?
  1.197  MATH         Done = NOT(MEM1)

  1.198  IF           Done
# Force a "FAIL" condition, since data could not be obtained.
  1.199  EVAL   -e 0 : [V Msg]
  2.001  MATH         @Abort = 1
  2.002  ELSE
  2.003  MATH         @ShowConnection = 1
  2.004  ENDIF

  2.005  ENDIF

  2.006  UNTIL        Done || @Abort

  2.007  HEAD         -2
  2.008  9500         *                                                 S
  2.009  END
